from flask import redirect, jsonify

from api.route import Route
from core.logger import Logger
from data.schemas.public.short_url import ShortUrl
from data.schemas.public.short_url_dao import shortUrlDao

logger = Logger(__name__)


@Route.get(f"/api/find/<path:path>")
async def find(path: str):
    from_db = await shortUrlDao.find_single_by({ShortUrl.short_url: path})
    if from_db is None:
        return jsonify(None)

    return jsonify(from_db.to_dto())


@Route.get(f"/api/redirect/<path:path>")
async def handle_short_url(path: str):
    if path.startswith("api/"):
        path = path.replace("api/", "")

    from_db = await shortUrlDao.find_single_by({ShortUrl.short_url: path})
    if from_db is None:
        return {"error": "Short URL not found"}, 404

    return redirect(from_db.target_url)
